#!/bin/sh

# This helper script will handle deploying a s3 bucket
set -e

source /scripts/utils.sh
source /scripts/terraform.sh


check_access ${appsNamespace} configmaps

tfAdditionalVarsFile=${tfRoot}/additional_settings.auto.tfvars

## add the values for the glue job or glue crawler that needs to be executed when the trigger occurs.

#adds the job name if the trigger is for a job
if [ ! -z "${jobName}" ]; then
echo "glue_job_name = \"${jobName}\"" >> ${tfAdditionalVarsFile}
fi

#adds the crawler name if the trigger is for a crawler
if [ ! -z "${crawlerName}" ]; then
echo "glue_crawler_name = \"${crawlerName}\"" >> ${tfAdditionalVarsFile}
fi

# Sets the terraform variable for s3 script location for glue
echo "glue_job_script_location = \"s3://${scriptLocationBucket}${scriptPath}\"" >> ${tfAdditionalVarsFile}

#adds the predicate conditions
conditions=()

echo "the states are $states"
echo "the logical_operators are $logicalOperators"
state=(${states})
logicalOperator=(${logicalOperators})

for index in "${!state[@]}";
do
    job_name="job_"$index
    crawler_name="crawler_"$index
    if [ ! -z "$(printenv "${job_name}")" ]; then
        dict=$( printf "{\"state\" = \"${state[$index]}\", \"logical_operator\" = \"${logicalOperator[$index]}\", \"job_name\" = \"$(printenv "${job_name}")\" }," )
        conditions+=($dict)
    else
        dict=$( printf "{ \"crawl_state\" = \"${state[$index]}\" ,\"logical_operator\" = \"${logicalOperator[$index]}\", \"crawl_name\" = \"$(printenv "${crawler_name}")\" }," )
        conditions+=($dict)
    fi
done

echo "the conditions are [ ${conditions[@]} ] "
echo "predicate_conditions = [ ${conditions[@]} ]" >> ${tfAdditionalVarsFile}

terraform_init
terraform_plan
terraform_apply
terraform_output

print_header "Dump output to ConfigMap"
arnConfigMapName=${namingPrefix}-arn
terraform_get arn arnValue

cat >/tmp/config.yaml <<EOF
apiVersion: v1
kind: ConfigMap
metadata:
  name: ${arnConfigMapName}
data:
  ARN: ${arnValue}
EOF

run_cmd cat "/tmp/config.yaml"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} apply -f /tmp/config.yaml
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${infraNamespace} apply -f /tmp/config.yaml

echo "Config map ${arnConfigMapName}"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} get cm ${arnConfigMapName} -o yaml

cprint "$0 done "
